#
# spec file for package signing-party
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           signing-party
Version:        2.1
Release:        10.3.1
Summary:        GPG Tools
License:        GPL-2.0-or-later
Group:          Productivity/Security
Url:            http://pgp-tools.alioth.debian.org/
Source:         http://ftp.debian.org/debian/pool/main/s/signing-party/signing-party_%{version}.orig.tar.gz
# PATCH-FIX-OPENSUSE caff-manpage.patch [bnc#722626]
Patch1:         caff-manpage.patch
# PATCH-FIX-OPENSUSE bnc#955986
Patch2:         caff-perl_5.18_compatibility.patch
# PATCH-FIX-UPSTREAM cve-2019-11627.patch boo#1134040
Patch3:         cve-2019-11627.patch
Requires:       %{_sbindir}/sendmail
Requires:       gpg
Requires:       perl
Requires:       perl-GnuPG-Interface
Requires:       perl-MIME-tools
Requires:       perl-MailTools
Requires:       perl-Net-IDN-Encode
Requires:       perl-Text-Template
Requires:       qprint
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# We are not including keyanalyze which gets compiled and therefore
# the package is noarch
BuildArch:      noarch

%description
PGP Tools is a collection for all kinds of pgp related things, including signing scripts, party preparation scripts etc.

caff is a script that helps you in keysigning. It takes a list of
keyids on the command line, fetches them from a keyserver and calls
GnuPG so that you can sign it. It then mails each key to all its email
addresses - only including the one UID that we send to in each mail.

pgp-clean takes a list of keyids on the command line and outputs an
ascii-armored keyring on stdout for each key with all signatures
except self-signatures stripped. Its use is to reduce the size of keys
sent out after signing. (pgp-clean is a stripped-down caff version.)

gpg-key2ps will output a PostScript file which has your Key-ID, UIDs
and fingerprint nicely formatted for printing paper slips to take with
you to a signing-party.

Given one or more key-ids, gpg-mailkeys mails these keys to their
owners. You use this after you've signed them. By default, the mails
contain a standard text and your name and address as the From (as
determined by the sendmail command).

gpglist takes a keyid and creates a listing showing who signed your
user IDs.

gpgsigs was written to assist the user in signing keys during a
keysigning party. It takes as input a file containing keys in gpg
--list-keys format and prepends every line with a tag indicating if
the user has already signed that uid.

keylookup is a wrapper around gpg --search, allowing you to search for
keys on a keyserver. It presents the list of matching keys to the user
and allows her to select the keys for importing into the GnuPG
keyring.

%prep
%setup -q -n signing-party-%{version} -c -a0
%patch1 -p1
%patch2 -p1
%patch3 -p1
rm -rf keyanalyze

%build
make %{?_smp_mflags} CFLAGS="%{optflags}"

%install
mkdir -p %{buildroot}
install -d d %{buildroot}%{_bindir}
install -m 755 caff/caff caff/pgp-clean caff/pgp-fixkey %{buildroot}%{_bindir}
install -m 755 gpglist/gpglist %{buildroot}%{_bindir}
install -m 755 gpg-key2ps/gpg-key2ps %{buildroot}%{_bindir}
install -m 755 gpglist/gpglist %{buildroot}%{_bindir}
install -m 755 gpg-mailkeys/gpg-mailkeys %{buildroot}%{_bindir}
install -m 755 gpgsigs/gpgsigs %{buildroot}%{_bindir}
install -m 755 keylookup/keylookup %{buildroot}%{_bindir}
install -m 755 keyart/keyart %{buildroot}%{_bindir}

install -d %{buildroot}%{_mandir}/man1
install -m 644 caff/caff.1 caff/pgp-clean.1 caff/pgp-fixkey.1 %{buildroot}%{_mandir}/man1
install -m 644 gpg-key2ps/gpg-key2ps.1 %{buildroot}%{_mandir}/man1
install -m 644 gpglist/gpglist.1 %{buildroot}%{_mandir}/man1
install -m 644 gpg-mailkeys/gpg-mailkeys.1 %{buildroot}%{_mandir}/man1
install -m 644 gpgsigs/gpgsigs.1 %{buildroot}%{_mandir}/man1
install -m 644 keylookup/keylookup.1 %{buildroot}%{_mandir}/man1
install -m 644 keyart/doc/keyart.1 %{buildroot}%{_mandir}/man1

%files
%defattr(-, root, root)
%doc caff/README caff/README.gpg-agent caff/README.many-keys caff/README.v3-keys caff/caffrc.sample
%doc gpgsigs/gpgsigs-lt2k5*.txt gpg-mailkeys/example.gpg-mailkeysrc
%doc keylookup/NEWS
%{_bindir}/*
%{_mandir}/*/*

%changelog
* Fri May  3 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Add patch cve-2019-11627.patch from https://salsa.debian.org/signing-party-team/signing-party/commit/cd69b6c0426a6160ef3de03fce9c7f112166d5a8
  to fix CVE-2019-11627.
* Thu Nov 26 2015 vcizek@suse.com
- fix an incompatibility with perl 5.18 (boo#955986)
  * caff 2.x is using hash slices which were introduced in Perl 5.20
  * added caff-perl_5.18_compatibility.patch
* Sat Aug 22 2015 astieger@suse.com
- update to 2.1:
  * caff:
    + Only consider non-expired/invalid/revoked keys and UIDs when
    generating the caffrc.
    + Proper RFC 5322 validation of email addresses.
    + Prefix the signature by "-- \n" in the email template.
    + Automatically mkdir ~/.caff if it doesn't exit.
* Mon Jun 22 2015 astieger@suse.com
- update to 2.0 [boo#918402]
  * caff:
    + Fix broken compatibility with GnuPG 2.1 (2.1.3 and later only)
    + Default $CONFIG{'local-user'} to $CONFIG{'keyid'} rather than
    importing the public part of *all* keys found in the secret keyring.
    + error output handling improvements
    + Add a --debug flag to enable debug messages.
    + Send attachements and non RFC 2822 UIDs to *all* signed addresses, not
    only those for which the UID is exported.  This is useful when the
    signee has some already signed RFC 2822 UIDs and a freshly added
    attribute, for instance.
    + color ouput ($CONFIG{colors})
    + Prune keys with import-{clean,minimal} not export-{clean,minimal}.
    + Fix $CONFIG{'also-lsign-in-gnupghome'}: local signatures are directly
    imported from caff's GNUPGHOME to our own; in auto-lsign'ing mode, lsign
    UID for which we have an exportable signature (preserving the signer and
    cert level).
    + Pass the 'keyserver-options' specified in ~/.gnupg/gpg.conf to
    $CONFIG{keyserver} when it is left unset.
  * gpgsigs:
    + Add a legend with the different signature types.
    + Mark local signatures as 'L' (formerly they were marked as 'S'), and
    expiring -- but not expired -- signatures as 'x'.
  * caff, pgp-clean, pgp-fixkey, gpg-key2latex, gpg-key2ps, gpg-mailkeys,
    gpgdir, gpgparticipants, gpgsigs, keyart, keylookup:
    + Add the possibility to choose the gpg binary via the "GNUPGBIN"
    environment variable.  (Default: "gpg".)
* Wed Feb 18 2015 meissner@suse.com
- require new perl module in 1.1.12 perl-Net-IDN-Encode
* Wed Feb 18 2015 astieger@suse.com
- signing-party 1.1.12:
  * new keyart command
  * new options and commands
  * bug and compatibility fixes
* Sat Jan  5 2013 joop.boonen@opensuse.org
- Corrected the Url that links to the main page
* Thu Mar 22 2012 cfarrell@suse.com
- license update: GPL-2.0+
  Various Open Source Licenses is not acceptable as a spec file license.
  For this package, GPL-2.0+ seems to be the most accurate license choice
* Wed Mar 14 2012 joop.boonen@opensuse.org
- Build version 1.1.4
  * gpg-key2ps:
    + Apply patch from Uwe Kleine-König to deal with latin1 characters
  * gpg-mailkeys:
    + Correct path of ~/.gpg-mailkeysrc and ~/.signature in manpage.
    + Add new environment variable SENDMAIL_ARGS to allow user to pass
    arguments to sendmail
  * caff:
    + Correct path of ~/.caffrc in informational messages
    + Be more verbose on unexpected key ID
    + Refactor import of own key and import for keys to sign from keyrings.
    + Also automatically import keys to sign from the user's normal gpg
    keyrings.
    + Use --no-auto-check-trustdb when importing keys from files or
    the user's normal gpg keyrings
    + manpage: Refer to all of /usr/share/doc/signing-party/caff/ and not
    just to /usr/share/doc/signing-party/caff/caffrc.sample
    + Fix horrible &function calls used because of broken prototypes.
    + Even if all keys to sign were found in the user's normal gpg
    keyrings we still need to import them (again) from any keyrings
    passed with --key-files - the keys there might be newer, containing
    new subkeys (for encryption), uids (for signing) or revocations.
    + Make importing of keys to be signed from the normal gpg optional
    (--keys-from-gnupg).
    + refactor copying of command line options into global config variable.
    + Create the mail files in ~/.caff/keys even if mail is not sent
* Wed Oct 12 2011 aj@suse.de
- Fix caff manpage (bnc#722626)
- Run spec file through spec-cleaner
* Tue Oct 26 2010 aj@suse.de
- Make package noarch.
* Mon Jun 28 2010 joop.boonen@opensuse.org
- Build version 1.1.3
* Sat Sep 19 2009 aj@suse.de
- Fix Requires.
* Wed Aug 12 2009 aj@suse.de
- Update to version 1.1.1.
- Many bugfixes.
- New tools: keyanalyze, sig2dot, springgraph.
- Drop keylookup.
* Sat Mar  3 2007 aj@suse.de
- Add missing requires for caff.
- Update to version 0.4.9.
* Wed Sep 13 2006 aj@suse.de
- Initial package.
